"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.yeastStarterGrow = exports.yeastNeeded = exports.yeastCount = exports.carbonation = exports.calcCalories = exports.recalculateMashSteps = exports.calcMashGrainWeight = exports.calcMashVolumes = exports.calcBoilVolumes = exports.calculateRecipeBeerJSON = exports.bitternessRatio = exports.bitternessIbuTinseth = exports.bitternessIbuRager = exports.calcABV = exports.srmToRgb = exports.srmToCss = exports.calcColor = exports.calcBoilGravity = exports.calcFinalGravity = exports.calcOriginalGravity = exports.convertMeasurableValue = exports.convert = void 0;
const brewcalc_1 = require("./brewcalc");
Object.defineProperty(exports, "calcCalories", { enumerable: true, get: function () { return brewcalc_1.calcCalories; } });
Object.defineProperty(exports, "carbonation", { enumerable: true, get: function () { return brewcalc_1.carbonation; } });
Object.defineProperty(exports, "yeastCount", { enumerable: true, get: function () { return brewcalc_1.yeastCount; } });
Object.defineProperty(exports, "yeastNeeded", { enumerable: true, get: function () { return brewcalc_1.yeastNeeded; } });
Object.defineProperty(exports, "yeastStarterGrow", { enumerable: true, get: function () { return brewcalc_1.yeastStarterGrow; } });
const hops_1 = require("./hops");
Object.defineProperty(exports, "bitternessIbuRager", { enumerable: true, get: function () { return hops_1.bitternessIbuRager; } });
Object.defineProperty(exports, "bitternessIbuTinseth", { enumerable: true, get: function () { return hops_1.bitternessIbuTinseth; } });
Object.defineProperty(exports, "bitternessRatio", { enumerable: true, get: function () { return hops_1.bitternessRatio; } });
const utils_1 = require("./utils");
const units_1 = require("./units");
Object.defineProperty(exports, "convertMeasurableValue", { enumerable: true, get: function () { return units_1.convertMeasurableValue; } });
const converter_1 = require("./converter/converter");
Object.defineProperty(exports, "convert", { enumerable: true, get: function () { return converter_1.convert; } });
const mash_1 = require("./mash");
Object.defineProperty(exports, "calcMashGrainWeight", { enumerable: true, get: function () { return mash_1.calcMashGrainWeight; } });
Object.defineProperty(exports, "recalculateMashSteps", { enumerable: true, get: function () { return mash_1.recalculateMashSteps; } });
const volumes_1 = require("./volumes");
Object.defineProperty(exports, "calcBoilVolumes", { enumerable: true, get: function () { return volumes_1.calcBoilVolumes; } });
Object.defineProperty(exports, "calcMashVolumes", { enumerable: true, get: function () { return volumes_1.calcMashVolumes; } });
const gravity_1 = require("./gravity");
Object.defineProperty(exports, "calcOriginalGravity", { enumerable: true, get: function () { return gravity_1.calcOriginalGravity; } });
Object.defineProperty(exports, "calcFinalGravity", { enumerable: true, get: function () { return gravity_1.calcFinalGravity; } });
Object.defineProperty(exports, "calcBoilGravity", { enumerable: true, get: function () { return gravity_1.calcBoilGravity; } });
const color_1 = require("./color");
Object.defineProperty(exports, "srmToCss", { enumerable: true, get: function () { return color_1.srmToCss; } });
Object.defineProperty(exports, "srmToRgb", { enumerable: true, get: function () { return color_1.srmToRgb; } });
Object.defineProperty(exports, "calcColor", { enumerable: true, get: function () { return color_1.calcColor; } });
const abv_1 = require("./abv");
Object.defineProperty(exports, "calcABV", { enumerable: true, get: function () { return abv_1.calcABV; } });
const calculateRecipeBeerJSON = (recipe, mash, equipment) => {
    const { batch_size, boil, efficiency, ingredients } = recipe;
    const { fermentable_additions, hop_additions, culture_additions } = ingredients;
    let original_gravity = {
        unit: 'sg',
        value: null,
    };
    let final_gravity = {
        unit: 'sg',
        value: null,
    };
    let color = {
        unit: 'SRM',
        value: null,
    };
    let ibu = {
        unit: 'IBUs',
        value: null,
    };
    let abv = {
        unit: '%',
        value: null,
    };
    let volumes = null;
    let calculatedMash = null;
    let calculatedBoil = null;
    if (utils_1.isNotEmptyArray(fermentable_additions)) {
        original_gravity = gravity_1.calcOriginalGravity(batch_size, fermentable_additions, efficiency);
        const defaultCultureAddition = {
            name: 'Default Culture',
            type: 'ale',
            form: 'liquid',
            attenuation: { value: 75, unit: '%' },
        };
        final_gravity = gravity_1.calcFinalGravity(batch_size, fermentable_additions, efficiency, utils_1.isNotEmptyArray(culture_additions)
            ? culture_additions
            : [defaultCultureAddition]);
        abv = abv_1.calcABV(original_gravity, final_gravity);
        const { pre_boil_size } = volumes_1.calcBoilVolumes(batch_size, boil, equipment);
        volumes = {
            pre_boil_size,
        };
        if (mash) {
            const mashGrainWeight = mash_1.calcMashGrainWeight(fermentable_additions);
            const mashSteps = mash_1.recalculateMashSteps(mash.mash_steps, mash.grain_temperature, mashGrainWeight);
            const { sparge_volume, mash_volume, total_volume } = volumes_1.calcMashVolumes(pre_boil_size, mashSteps, mashGrainWeight, equipment);
            volumes = Object.assign(Object.assign({}, volumes), { sparge_volume,
                mash_volume,
                total_volume });
            calculatedMash = Object.assign(Object.assign({}, mash), { mash_steps: mash_1.updateSpargeVolume(mashSteps, sparge_volume) });
        }
        if (boil) {
            calculatedBoil = Object.assign(Object.assign({}, boil), { pre_boil_size });
        }
        color = color_1.calcColor(fermentable_additions, batch_size);
        if (utils_1.isNotEmptyArray(hop_additions)) {
            const boilGravity = gravity_1.calcBoilGravity(batch_size, pre_boil_size, original_gravity);
            ibu = hops_1.bitternessIbuTinseth(hop_additions, boilGravity, batch_size);
        }
    }
    return {
        stats: {
            original_gravity: utils_1.roundMeasurable(original_gravity, 3),
            final_gravity: utils_1.roundMeasurable(final_gravity, 3),
            alcohol_by_volume: utils_1.roundMeasurable(abv, 1),
            ibu_estimate: utils_1.roundMeasurable(ibu, 1),
            color_estimate: utils_1.roundMeasurable(color, 1),
        },
        volumes,
        mash: calculatedMash,
        boil: calculatedBoil,
    };
};
exports.calculateRecipeBeerJSON = calculateRecipeBeerJSON;
/*export {
  scaleRecipe,
  calcWaterChemistry,
}*/
//# sourceMappingURL=index.js.map