"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.roundMeasurable = exports.getMeasurableValue = exports.isMeasurable = exports.isObject = exports.round = exports.isNotEmptyArray = exports.capitalize = exports.sum = exports.lovibondToSrm = exports.srmToLovibond = exports.ebcToSrm = exports.srmToEbc = exports.sgToBrix = exports.brixToSG = exports.platoToSG = exports.sgToPlato = exports.psiTokpa = exports.kpaToPsi = exports.celsiusToFahrenheit = exports.fahrenheitToCelsius = exports.gallonsToLiters = exports.litersToGallons = exports.ouncesToLiters = exports.litersToOunces = exports.poundsTokg = exports.kgToPounds = exports.kgToOunces = void 0;
const kgToOunces = (k) => k * 35.2739619;
exports.kgToOunces = kgToOunces;
const kgToPounds = (k) => exports.kgToOunces(k) / 16;
exports.kgToPounds = kgToPounds;
const poundsTokg = (p) => p / 2.204;
exports.poundsTokg = poundsTokg;
const litersToOunces = (l) => l / 0.0295735;
exports.litersToOunces = litersToOunces;
const ouncesToLiters = (o) => o * 0.0295735;
exports.ouncesToLiters = ouncesToLiters;
const litersToGallons = (l) => exports.litersToOunces(l) / 128;
exports.litersToGallons = litersToGallons;
const gallonsToLiters = (g) => exports.ouncesToLiters(g * 128);
exports.gallonsToLiters = gallonsToLiters;
const fahrenheitToCelsius = (f) => (f - 32) / 1.8;
exports.fahrenheitToCelsius = fahrenheitToCelsius;
const celsiusToFahrenheit = (c) => c * 1.8 + 32;
exports.celsiusToFahrenheit = celsiusToFahrenheit;
const kpaToPsi = (kpa) => kpa * 0.14503773773020923;
exports.kpaToPsi = kpaToPsi;
const psiTokpa = (psi) => psi * 6.894757293168361;
exports.psiTokpa = psiTokpa;
const sgToPlato = (sg) => -616.868 +
    1111.14 * sg -
    630.272 * Math.pow(sg, 2) +
    135.997 * Math.pow(sg, 3);
exports.sgToPlato = sgToPlato;
const platoToSG = (e) => 1 + e / (258.6 - (e / 258.2) * 227.1);
exports.platoToSG = platoToSG;
const brixToSG = (brix) => brix / (258.6 - (brix / 258.2) * 227.1) + 1;
exports.brixToSG = brixToSG;
const sgToBrix = (sg) => -669.5622 +
    1262.7749 * sg -
    775.6821 * Math.pow(sg, 2) +
    182.4601 * Math.pow(sg, 3);
exports.sgToBrix = sgToBrix;
const srmToEbc = (srm) => srm * 1.97;
exports.srmToEbc = srmToEbc;
const ebcToSrm = (ebc) => ebc * 0.508;
exports.ebcToSrm = ebcToSrm;
const srmToLovibond = (srm) => (srm + 0.76) / 1.3546;
exports.srmToLovibond = srmToLovibond;
const lovibondToSrm = (lovibond) => 1.3546 * lovibond - 0.76;
exports.lovibondToSrm = lovibondToSrm;
const sum = (array) => array.reduce((pv, cv) => pv + cv, 0);
exports.sum = sum;
const scaleIngredients = (scaleFactor, ingredients) => ingredients.map((i) => {
    return Object.assign(Object.assign({}, i), { amount: scaleFactor * i.amount });
});
const capitalize = (str) => {
    const words = str.split(' ');
    const capitalizedWords = words.map((word) => word.charAt(0).toUpperCase() + word.slice(1));
    return capitalizedWords.join(' ');
};
exports.capitalize = capitalize;
const isNotEmptyArray = (arr) => {
    if (Array.isArray(arr)) {
        return arr.length > 0;
    }
    return false;
};
exports.isNotEmptyArray = isNotEmptyArray;
function round(number, precision = 0) {
    if (typeof number === 'number') {
        return Number(number.toFixed(precision));
    }
    return null;
}
exports.round = round;
function isObject(object) {
    return object != null && typeof object === 'object';
}
exports.isObject = isObject;
function isMeasurable(object) {
    return (isObject(object) &&
        object.hasOwnProperty('value') &&
        object.hasOwnProperty('unit'));
}
exports.isMeasurable = isMeasurable;
function getMeasurableValue(measurable) {
    if (isMeasurable(measurable)) {
        return measurable.value;
    }
    return null;
}
exports.getMeasurableValue = getMeasurableValue;
const roundMeasurable = (m, precision) => {
    return {
        unit: m.unit,
        value: round(m.value, precision),
    };
};
exports.roundMeasurable = roundMeasurable;
//# sourceMappingURL=utils.js.map